==> haskell-authenticate-oauth-1.7-225-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 authenticate-oauth
version:              1.7
visibility:           public
id:                   authenticate-oauth-1.7-Gs2w3HaLCE8EyinEUdnKZW
key:                  authenticate-oauth-1.7-Gs2w3HaLCE8EyinEUdnKZW
license:              BSD-3-Clause
maintainer:           Hiromi Ishii, Artem Chirkin
author:               Hiromi Ishii
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:
    Library to authenticate with OAuth for Haskell web applications.

description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.

category:             Web
abi:                  6404f3ae9225726d701503cebb021e70
exposed:              True
exposed-modules:      Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs:          /usr/lib/ghc-9.2.8/site-local/authenticate-oauth-1.7
library-dirs:         /usr/lib/ghc-9.2.8/site-local/authenticate-oauth-1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate-oauth
hs-libraries:         HSauthenticate-oauth-1.7-Gs2w3HaLCE8EyinEUdnKZW
depends:
    RSA-2.4.1-4b4kJzUXS7ibfbnHRMA8Z SHA-1.6.4.4-4vZ3YEU9upt6TqgW7hflaa
    base-4.16.4.0 base64-bytestring-1.2.1.0-6ICZKEZtNauKUlSfxjYXGw
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    crypto-pubkey-types-0.4.3-I2PcGmyEWTDLIjLWJKJZEP
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    http-client-0.7.15-6rghVcd2UtiEi8qv3482QX
    http-types-0.12.4-BHydc54DAW314d9zE8t9hR
    random-1.2.1.2-LCKSS7rEcRbACR8x8dKjFH time-1.11.1.1
    transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS

haddock-interfaces:
    /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock

haddock-html:         /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-oauth-1.7-226-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 authenticate-oauth
version:              1.7
visibility:           public
id:                   authenticate-oauth-1.7-NOU45Vwgjo5l3ieNhDhhK
key:                  authenticate-oauth-1.7-NOU45Vwgjo5l3ieNhDhhK
license:              BSD-3-Clause
maintainer:           Hiromi Ishii, Artem Chirkin
author:               Hiromi Ishii
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:
    Library to authenticate with OAuth for Haskell web applications.

description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.

category:             Web
abi:                  4167bcae87075d9a7ecba0510981c815
exposed:              True
exposed-modules:      Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs:          /usr/lib/ghc-9.2.8/site-local/authenticate-oauth-1.7
library-dirs:         /usr/lib/ghc-9.2.8/site-local/authenticate-oauth-1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate-oauth
hs-libraries:         HSauthenticate-oauth-1.7-NOU45Vwgjo5l3ieNhDhhK
depends:
    RSA-2.4.1-4b4kJzUXS7ibfbnHRMA8Z SHA-1.6.4.4-4vZ3YEU9upt6TqgW7hflaa
    base-4.16.4.0 base64-bytestring-1.2.1.0-6ICZKEZtNauKUlSfxjYXGw
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    crypto-pubkey-types-0.4.3-I2PcGmyEWTDLIjLWJKJZEP
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    http-client-0.7.15-61h4VWVLBXSHlmXDYXGwwU
    http-types-0.12.4-54A2bJ1fQUxAhnyu8WH6Th
    random-1.2.1.2-LCKSS7rEcRbACR8x8dKjFH time-1.11.1.1
    transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS

haddock-interfaces:
    /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock

haddock-html:         /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
